@@ -127,7 +127,7 @@ all app state variables as a dict is determining the method
 Changed app state value that need to be propagated also to the framework
 app instance should be set not via the instance attribute, instead call
 the method :meth:`~MainBaseApp.change_app_state` (which ensures the
-propagation to any duplicated value in a (bound) framework property).
+propagation to any duplicated (observable/bound) framework property).
 
 For to to save the app state to the :ref:`config-files` the implementing main app
 instance has to call the method :meth:`~MainBaseApp.save_app_states` - this could be
@@ -182,7 +182,7 @@ from ae.console import ConsoleApp               # type: ignore
 from ae.files import FilesRegister, CachedFile  # type: ignore
 
 
-__version__ = '0.0.3'
+__version__ = '0.0.5'
 
 
 AppStateType = Dict[str, Any]           #: app state config variable type
@@ -217,8 +217,8 @@ class MainAppBase(ConsoleApp, ABC):
     def __init__(self, debug_bubble: bool = False, **console_app_kwargs):
         """ create instance of app class.
 
-        :param debug_bubble:
-        :param console_app_kwargs:
+        :param debug_bubble:        pass True to activate debug bubble.
+        :param console_app_kwargs:  kwargs to be passed to the __init__ method of the super-class / ConsoleApp instance.
         """
         self.context_path = list()  # init for Literal type recognition - will be overwritten by setup_app_states()
         self.debug_bubble = debug_bubble
@@ -252,30 +252,64 @@ class MainAppBase(ConsoleApp, ABC):
             return tuple()
 
     def call_event(self, method: str, *args, **kwargs) -> Any:
-        """ dispatch event to inheriting instances. """
+        """ dispatch event to inheriting instances.
+
+        :param method:      name of the main app method to call.
+        :param args:        args passed to the main app method to be called.
+        :param kwargs:      kwargs passed to the main app method to be called.
+        :return:            return value of the called method or None if method does not exist.
+        """
         event_callback = getattr(self, method, None)
         if event_callback:
             return event_callback(*args, **kwargs)
         return None
 
     def change_app_state(self, state_name: str, new_value: Any):
-        """ change single app state item to value in self.attribute and app_state dict item. """
+        """ change single app state item to value in self.attribute and app_state dict item.
+
+        :param state_name:  name of the app state to change.
+        :param new_value:   new value of the app state to change.
+        """
         setattr(self, state_name, new_value)
-        if self.framework_app and self.framework_app.app_state:     # if framework needs duplicate DictProperty
-            self.framework_app.app_state[state_name] = new_value
+        self._change_observable(state_name, new_value)
+
+    def _change_observable(self, name: str, value: Any):
+        """ change observable attribute/member/property in framework_app instance.
+
+        :param name:    name of the observable attribute/member or key of an observable dict property.
+        :param value:   new value of the observable.
+        """
+        if self.framework_app:
+            if hasattr(self.framework_app, 'ae_states'):            # has observable DictProperty duplicates
+                self.framework_app.ae_states[name] = value
+            if hasattr(self.framework_app, 'ae_state_' + name):     # has observable attribute duplicate
+                setattr(self.framework_app, 'ae_state_' + name, value)
 
     def context_enter(self, context_id: str, next_context_id: str = ''):
-        """ user extending/entering/adding new context_id (e.g. navigates down in the app context path/tree) """
+        """ user extending/entering/adding new context_id (e.g. navigates down in the app context path/tree).
+
+        :param context_id:      context id/name to enter into.
+        :param next_context_id: context id within the entering/new child context.
+        """
         self.context_path.append(context_id)
         self.set_context(next_context_id)
 
     def context_leave(self, next_context_id: str = ''):
-        """ user navigates up in the data tree """
+        """ user navigates up in the data tree.
+
+        :param next_context_id: context id to set in the parent context.
+        """
         list_name = self.context_path.pop()
         self.set_context(next_context_id or list_name)
 
     def find_image_file(self, image_name: str, height: float = 32.0, light_theme: bool = True) -> str:
-        """ find best fitting image in img app folder. """
+        """ find best fitting image in img app folder.
+
+        :param image_name:      name of the image (file name without extension).
+        :param height:          preferred height of the image/icon.
+        :param light_theme:     preferred thema (dark/light) of the image.
+        :return:                image file path if found else empty string.
+        """
         def property_matcher(file):
             """ find images with enough height """
             return file.properties.get('height', 32.0) >= height and bool(file.properties.get('dark', 0)) != light_theme
@@ -291,7 +325,11 @@ class MainAppBase(ConsoleApp, ABC):
         return ''
 
     def find_sound(self, sound_name: str) -> Optional[CachedFile]:
-        """ find sound by name. """
+        """ find sound by name.
+
+        :param sound_name:      name of the sound to search for.
+        :return:                cached sound file if sound name was found else None.
+        """
         if self.sound_files:    # prevent error on app startup (setup_app_states() called before load_images()
             return self.sound_files(sound_name)
         return None
@@ -326,15 +364,24 @@ class MainAppBase(ConsoleApp, ABC):
         self.po(chr(7), "BEEP")
 
     def play_sound(self, sound_name: str):
-        """ play audio/sound file, should be overwritten by GUI framework. """
+        """ play audio/sound file, should be overwritten by GUI framework.
+
+        :param sound_name:  name of the sound to play.
+        """
         self.po(f"play_sound {sound_name}")
 
     def play_vibrate(self, pattern: Tuple = (0.0, 0.3)):
-        """ play vibrate pattern, should be overwritten by GUI framework. """
+        """ play vibrate pattern, should be overwritten by GUI framework.
+
+        :param pattern:     tuple of pause and vibrate time sequence.
+        """
         self.po(f"play_vibrate {pattern}")
 
     def retrieve_app_states(self) -> AppStateType:
-        """ determine the state of a running app from the config files and return it as dict """
+        """ determine the state of a running app from the config files and return it as dict.
+
+        :return:    dict with all app states available in the config files.
+        """
         app_state = dict()
         for key in self.app_state_keys():
             app_state[key] = getattr(self, key)
@@ -342,7 +389,10 @@ class MainAppBase(ConsoleApp, ABC):
         return app_state
 
     def save_app_states(self) -> str:
-        """ save app state in config file """
+        """ save app state in config file.
+
+        :return:    empty string if app status could be saved into config files else error message.
+        """
         err_msg = ""
 
         app_state = self.retrieve_app_states()
@@ -367,12 +417,18 @@ class MainAppBase(ConsoleApp, ABC):
             self.call_event('on_context_draw')
 
     def set_font_size(self, font_size: float):
-        """ change font size. """
+        """ change font size.
+
+        :param font_size:   font size in pixels.
+        """
         self.change_app_state('font_size', font_size)
         self.call_event('on_context_draw')
 
     def setup_app_states(self, app_state: AppStateType):
-        """ put app state variables into main app instance for to prepare framework app.run_app """
+        """ put app state variables into main app instance for to prepare framework app.run_app.
+
+        :param app_state:   dict of app states.
+        """
         for key, val in app_state.items():
             self.change_app_state(key, val)
 
@@ -390,3 +446,12 @@ class MainAppBase(ConsoleApp, ABC):
             key, val = APP_STATE_VERSION_VAR_NAME, APP_STATE_CURRENT_VERSION
             self.change_app_state(key, val)
             self.set_var(key, val, section=APP_STATE_SECTION_NAME)
+
+    def _update_observable_app_states(self, app_state: AppStateType):
+        """ update all the observable app states.
+
+        :param app_state:   dict of app states.
+        """
+        if self.framework_app:
+            for key, val in app_state.items():
+                self._change_observable(key, val)
